sequencetools.partition_sequence_by_weights_at_least
====================================================

.. autofunction:: abjad.tools.sequencetools.partition_sequence_by_weights_at_least.partition_sequence_by_weights_at_least
